#include <acado_optimal_control.hpp>
#include <gnuplot/acado2gnuplot.hpp>


int main( ){

    USING_NAMESPACE_ACADO;

    // VARIABLES:
    // ------------------------
    DifferentialState        x;   // Position of the trolley
    ....

    Parameter                T;   // the end time
    Control                 ax;   // trolley accelaration


    // DIFFERENTIAL EQUATION:
    // ------------------------
    DifferentialEquation f( t_start, T );   // The model equations

    f << ...  // use the model equations from the exercise text


    // DEFINE AN OPTIMAL CONTROL PROBLEM:
    // ----------------------------------

    const int numberOfIntervals = 40;

    OCP ocp(t_start, T, numberOfIntervals);
    ocp.minimizeMayerTerm( T );
    ocp.subjectTo( f );

    ocp.subjectTo( AT_START, x == 0.0  );
    ocp.subjectTo( AT_END  , x == 10.0 );

    ocp.subjectTo(  0.0 <= T  <= 10.0  );

    ... // implement the other constraints.


    // DEFINE A PLOT WINDOW:
    // ---------------------
    GnuplotWindow window;
        window.addSubplot( x   ,"POSITION OF THE TROLLEY:  x"    );
        window.addSubplot( v   ,"VELOCITY OF THE TROLLEY:  v"    );
        window.addSubplot( phi ,"EXCITATION ANGLE       :  phi"  );
        window.addSubplot( dphi,"ANGULAR VELOCITY       :  dphi" );
        window.addSubplot( ax  ,"THE CONTROL INPUT      :  ax"   );


    // DEFINE AN OPTIMIZATION ALGORITHM AND SOLVE THE OCP:
    // ---------------------------------------------------
    OptimizationAlgorithm algorithm(ocp);
    algorithm << window;
    algorithm.solve();

    return 0;
}
